@@ -1,5 +1,5 @@
 package MooseX::Aliases;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Moose::Exporter;
 use Scalar::Util qw(blessed);
@@ -10,7 +10,7 @@ MooseX::Aliases - easy aliasing of methods and attributes in Moose
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -24,10 +24,10 @@ version 0.04
         alias => 'that',
     );
 
-    sub foo { say $self->that }
-    alias foo => 'bar';
+    sub foo { my $self = shift; print $self->that }
+    alias bar => 'foo';
 
-    $o = MyApp->new();
+    my $o = MyApp->new();
     $o->this('Hello World');
     $o->bar; # prints 'Hello World'
 
@@ -35,6 +35,7 @@ or
 
     package MyApp::Role;
     use Moose::Role;
+    use MooseX::Aliases;
 
     has this => (
         isa   => 'Str',
@@ -43,13 +44,13 @@ or
         alias => 'that',
     );
 
-    sub foo { say $self->that }
-    alias foo => 'bar';
+    sub foo { my $self = shift; print $self->that }
+    alias bar => 'foo';
 
 =head1 DESCRIPTION
 
-The MooseX::Aliases module will allow you to quickly alias methods in Moose.
-It provides an alias parameter for has() to generate aliased accessors as well
+The MooseX::Aliases module will allow you to quickly alias methods in Moose. It
+provides an alias parameter for C<has()> to generate aliased accessors as well
 as the standard ones. Attributes can also be initialized in the constructor via
 their aliased names.
 
@@ -60,7 +61,7 @@ their aliased names.
 =cut
 
 Moose::Exporter->setup_import_methods(
-    with_caller               => ['alias'],
+    with_meta                 => ['alias'],
     attribute_metaclass_roles => ['MooseX::Aliases::Meta::Trait::Attribute'],
 );
 
@@ -81,21 +82,30 @@ sub _get_method_metaclass {
     }
 }
 
-=head2 alias METHODNAME ALIAS
+=head2 alias ALIAS METHODNAME
 
-Gives the METHODNAME method an alias of ALIAS.
+Installs ALIAS as a method that is aliased to the method METHODNAME.
 
 =cut
 
 sub alias {
-    my ( $caller, $orig, $alias ) = @_;
-    my $meta   = Class::MOP::class_of($caller);
+    my ( $meta, $alias, $orig ) = @_;
     my $method = $meta->find_method_by_name($orig);
-    Moose->throw_error("cannot find method $orig to alias") unless $method;
+    if (!$method) {
+        $method = $meta->find_method_by_name($alias);
+        if ($method) {
+            Carp::cluck(
+                q["alias $from => $to" is deprecated, please use ]
+              . q["alias $to => $from"]
+            );
+            ($alias, $orig) = ($orig, $alias);
+        }
+    }
+    Moose->throw_error("Cannot find method $orig to alias") unless $method;
     $meta->add_method(
         $alias => _get_method_metaclass($method)->wrap(
             sub { shift->$orig(@_) }, # goto $_[0]->can($orig) ?
-            package_name => $caller,
+            package_name => $meta->name,
             name         => $alias,
             aliased_from => $orig
         )
@@ -109,6 +119,13 @@ associate the metaclass trait with your attribute. This is because Moose won't
 automatically apply metaclass traits to attributes in roles. The example in
 L<SYNOPSIS> should work.
 
+The order of arguments for the C<alias> method has changed (as of version
+0.05). I think the new order makes more sense, and it will make future
+refactoring I have in mind easier. The old order still works (although it gives
+a deprecation warning), unless you were relying on being able to override an
+existing method with an alias - this will now override in the other direction.
+The old argument order will be removed in a future release.
+
 Please report any bugs through RT: email
 C<bug-moosex-aliases at rt.cpan.org>, or browse to
 L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=MooseX-Aliases>.
